<?php
/**
 * The main template file
 *
 * This is the most generic template file in a WordPress theme
 * and one of the two required files for a theme (the other being style.css).
 * It is used to display a page when nothing more specific matches a query.
 * E.g., it puts together the home page when no home.php file exists.
 *
 * @link https://codex.wordpress.org/Template_Hierarchy
 *
 * @since Reef 0.1
 */
get_header();
if( is_front_page() ){
	/**
	* Prints sliders
	* 
	* @since Reef 0.1
	* @hooked reef_home_slider 10
	* @path inc/hooks/homepage-slider.php
	*/
	do_action( 'reef_home_page_slider' );

	/**
	* Prints Hightlighted Posts
	* 
	* @since Reef 0.1
	* @hooked reef_highlighted_posts 10
	* @path inc/hooks/reef-highlighted-posts.php
	*/
	do_action( 'reef_home_highlighted_posts' );
}else{

	/**
	* Prints Title and  breadcrumbs for archive pages
	*
	* @since Reef 0.1
	*/
	reef_inner_banner();
}
?>
<section class="wrapper wrap-list-page" id="main-content">
	<div class="row">
		<div class="col-xs-12 col-sm-7 col-md-8">
			<main id="main" class="post-detail-content"  role="main">
			<?php 
				
				if ( have_posts() ) : 
					# Start the Loop
					while ( have_posts() ) : the_post();
						get_template_part( 'template-parts/post/content', get_post_format() );
					endwhile;
				else :
					get_template_part( 'template-parts/post/content', 'none' );
				endif;

				the_posts_pagination( array(
					'next_text' => '<span>'.esc_html__( 'Next', 'reef' ) .'</span><span class="screen-reader-text">' . esc_html__( 'Next page', 'reef' ) . '</span>',
					'prev_text' => '<span>'.esc_html__( 'Prev', 'reef' ) .'</span><span class="screen-reader-text">' . esc_html__( 'Previous page', 'reef' ) . '</span>',
					'before_page_number' => '<span class="meta-nav screen-reader-text">' . esc_html__( 'Page', 'reef' ) . ' </span>',
				) );
			?>
			</main>
		</div>
		<?php get_sidebar(); ?>
	</div>
</section>

<?php 
/**
* Hooked Testimonial
*
* @since Reef 0.1
* @hooked reef_testimonial - 10
* @link inc/hooks/reef-testimonial.php
*/
do_action( 'reef_after_content' );

get_footer();