<?php
/**
* Reef: Excerpt
*
* @since Reef: 0.1
*/
if( ! class_exists( 'Reef_Excerpt' ) ):

class Reef_Excerpt{

    /**
    * Default length (by WordPress)
    *
    * @since Reef 0.1
    * @access public
    * @var int
    */
    public $length = 55;

    /**
    * So you can call: reef_excerpt( 'short' );
    *
    * @since  Reef 0.1
    * @access protected
    * @var    array
    */
    protected $types = array(
        'short'   => 25,
        'regular' => 55,
        'long'    => 100
    );

    /**
    * Stores class instance
    * 
    * @since  Reef 0.1
    * @access protected
    * @var    object
    */
    protected static $instance = NULL;

    /**
    * Retrives the instance of this class
    * 
    * @since  Reef 0.1
    * @access public
    * @return object
    */
    public static function get_instance() {

        if ( ! self::$instance ) {
          self::$instance = new self();
        }

        return self::$instance;
    }

    /**
    * Sets the length for the excerpt,then it adds the WP filter
    * And automatically calls the_excerpt();
    *
    * @since Reef 0.1
    * @param string $new_length 
    * @access public
    * @return void
    */
    public function excerpt( $new_length = 55, $echo ) {

        $this->length = $new_length;

        add_filter( 'excerpt_length', array( $this, 'new_length' ) );

        if( $echo )
          the_excerpt();
        else
          return get_the_excerpt();
    }

    /** 
    * Tells WP the new length
    *
    * @since Reef 0.1
    * @access public
    * @return int
    */
    public function new_length() {

        if( isset( $this->types[ $this->length ] ) )
          return $this->types[ $this->length ];
        else
          return $this->length;
    }
}

endif;

/**
* Call to Reef_Excerpt
*
* @since  1.0.0
* @uses   Reef_Excerpt:::get_instance()->excerpt()
* @param  int $length
* @return void
*/
if( ! function_exists( 'reef_excerpt' ) ):

    function reef_excerpt( $length = 55, $echo = true ) {
        $length = apply_filters( 'reef_excerpt_length', $length );
        return Reef_Excerpt::get_instance()->excerpt( $length, $echo );
    }
endif;